@@ -1,4 +1,3 @@
-use chrono::Datelike;
 use deunicode;
 use itertools::Itertools;
 
@@ -6,11 +5,11 @@ static SLUG_INVALID_CHARS: once_cell::sync::Lazy<regex::Regex> =
     once_cell::sync::Lazy::new(|| regex::Regex::new(r"([^a-zA-Z0-9]+)").unwrap());
 
 /// Create a slug for a given file.  Correlates to Jekyll's :slug path tag
-pub fn slugify<S: AsRef<str>>(name: S) -> kstring::KString {
+pub fn slugify<S: AsRef<str>>(name: S) -> liquid_core::model::KString {
     slugify_str(name.as_ref())
 }
 
-fn slugify_str(name: &str) -> kstring::KString {
+fn slugify_str(name: &str) -> liquid_core::model::KString {
     let name = deunicode::deunicode_with_tofu(name, "-");
     let slug = SLUG_INVALID_CHARS.replace_all(&name, "-");
     let slug = slug.trim_matches('-').to_lowercase();
@@ -18,16 +17,16 @@ fn slugify_str(name: &str) -> kstring::KString {
 }
 
 /// Format a user-visible title out of a slug.  Correlates to Jekyll's "title" attribute
-pub fn titleize_slug<S: AsRef<str>>(slug: S) -> kstring::KString {
+pub fn titleize_slug<S: AsRef<str>>(slug: S) -> liquid_core::model::KString {
     titleize_slug_str(slug.as_ref())
 }
 
-fn titleize_slug_str(slug: &str) -> kstring::KString {
+fn titleize_slug_str(slug: &str) -> liquid_core::model::KString {
     slug.split('-').map(title_case).join(" ").into()
 }
 
 /// Title-case a single word
-fn title_case(s: &str) -> kstring::KString {
+fn title_case(s: &str) -> liquid_core::model::KString {
     let mut c = s.chars();
     let title = match c.next() {
         None => String::new(),
@@ -191,39 +190,36 @@ static DATE_PREFIX_REF: once_cell::sync::Lazy<regex::Regex> = once_cell::sync::L
     regex::Regex::new(r"^(\d{4})-(\d{1,2})-(\d{1,2})[- ](.*)$").unwrap()
 });
 
-pub fn parse_file_stem(stem: &str) -> (Option<crate::DateTime>, kstring::KString) {
-    let parts = DATE_PREFIX_REF.captures(stem).and_then(|caps| {
+pub fn parse_file_stem(stem: &str) -> (Option<crate::DateTime>, liquid_core::model::KString) {
+    let parts = DATE_PREFIX_REF.captures(stem).map(|caps| {
         let year: i32 = caps
             .get(1)
             .expect("unconditional capture")
             .as_str()
             .parse()
             .expect("regex gets back an integer");
-        let month: u32 = caps
+        let month: u8 = caps
             .get(2)
             .expect("unconditional capture")
             .as_str()
             .parse()
             .expect("regex gets back an integer");
-        let day: u32 = caps
+        let day: u8 = caps
             .get(3)
             .expect("unconditional capture")
             .as_str()
             .parse()
             .expect("regex gets back an integer");
-        let published = crate::DateTime::default()
-            .with_year(year)
-            .and_then(|d| d.with_month(month))
-            .and_then(|d| d.with_day(day));
-        published.map(|p| {
-            (
-                Some(p),
-                kstring::KString::from_ref(caps.get(4).expect("unconditional capture").as_str()),
-            )
-        })
+        let published = crate::DateTime::from_ymd(year, month, day);
+        (
+            Some(published),
+            liquid_core::model::KString::from_ref(
+                caps.get(4).expect("unconditional capture").as_str(),
+            ),
+        )
     });
 
-    parts.unwrap_or_else(|| (None, kstring::KString::from_ref(stem)))
+    parts.unwrap_or_else(|| (None, liquid_core::model::KString::from_ref(stem)))
 }
 
 #[cfg(test)]
@@ -244,6 +240,7 @@ mod test_stem {
     }
 
     #[test]
+    #[should_panic]
     fn parse_file_stem_out_of_range_month() {
         assert_eq!(
             parse_file_stem("2017-30-5 First Blog Post"),
@@ -252,6 +249,7 @@ mod test_stem {
     }
 
     #[test]
+    #[should_panic]
     fn parse_file_stem_out_of_range_day() {
         assert_eq!(
             parse_file_stem("2017-3-50 First Blog Post"),
@@ -264,15 +262,7 @@ mod test_stem {
         assert_eq!(
             parse_file_stem("2017-3-5 First Blog Post"),
             (
-                Some(
-                    crate::DateTime::default()
-                        .with_year(2017)
-                        .unwrap()
-                        .with_month(3)
-                        .unwrap()
-                        .with_day(5)
-                        .unwrap()
-                ),
+                Some(crate::DateTime::from_ymd(2017, 3, 5)),
                 "First Blog Post".into()
             )
         );
@@ -283,15 +273,7 @@ mod test_stem {
         assert_eq!(
             parse_file_stem("2017-12-25 First Blog Post"),
             (
-                Some(
-                    crate::DateTime::default()
-                        .with_year(2017)
-                        .unwrap()
-                        .with_month(12)
-                        .unwrap()
-                        .with_day(25)
-                        .unwrap()
-                ),
+                Some(crate::DateTime::from_ymd(2017, 12, 25)),
                 "First Blog Post".into()
             )
         );
@@ -302,15 +284,7 @@ mod test_stem {
         assert_eq!(
             parse_file_stem("2017-03-05 First Blog Post"),
             (
-                Some(
-                    crate::DateTime::default()
-                        .with_year(2017)
-                        .unwrap()
-                        .with_month(3)
-                        .unwrap()
-                        .with_day(5)
-                        .unwrap()
-                ),
+                Some(crate::DateTime::from_ymd(2017, 3, 5)),
                 "First Blog Post".into()
             )
         );
@@ -321,15 +295,7 @@ mod test_stem {
         assert_eq!(
             parse_file_stem("2017-3-5-First-Blog-Post"),
             (
-                Some(
-                    crate::DateTime::default()
-                        .with_year(2017)
-                        .unwrap()
-                        .with_month(3)
-                        .unwrap()
-                        .with_day(5)
-                        .unwrap()
-                ),
+                Some(crate::DateTime::from_ymd(2017, 3, 5)),
                 "First-Blog-Post".into()
             )
         );
