@@ -203,18 +203,18 @@ pub fn create_new_project<P: AsRef<path::Path>>(dest: P) -> Result<()> {
 pub fn create_new_project_for_path(dest: &path::Path) -> Result<()> {
     fs::create_dir_all(dest)?;
 
-    create_file(&dest.join("_cobalt.yml"), COBALT_YML)?;
-    create_file(&dest.join("index.md"), INDEX_MD)?;
+    create_file(dest.join("_cobalt.yml"), COBALT_YML)?;
+    create_file(dest.join("index.md"), INDEX_MD)?;
 
-    fs::create_dir_all(&dest.join("_layouts"))?;
-    create_file(&dest.join("_layouts/default.liquid"), DEFAULT_LAYOUT)?;
+    fs::create_dir_all(dest.join("_layouts"))?;
+    create_file(dest.join("_layouts/default.liquid"), DEFAULT_LAYOUT)?;
 
-    fs::create_dir_all(&dest.join("posts"))?;
-    create_file(&dest.join("posts/post-1.md"), POST_MD)?;
+    fs::create_dir_all(dest.join("posts"))?;
+    create_file(dest.join("posts/post-1.md"), POST_MD)?;
 
-    fs::create_dir_all(&dest.join("_defaults"))?;
-    create_file(&dest.join("_defaults/pages.md"), INDEX_MD)?;
-    create_file(&dest.join("_defaults/posts.md"), POST_MD)?;
+    fs::create_dir_all(dest.join("_defaults"))?;
+    create_file(dest.join("_defaults/pages.md"), INDEX_MD)?;
+    create_file(dest.join("_defaults/posts.md"), POST_MD)?;
 
     Ok(())
 }
